@@ -111,7 +111,7 @@ thunar_progress_dialog_init (ThunarProgressDialog *dialog)
   gtk_widget_show (dialog->vbox);
 
   dialog->content_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-  gtk_container_set_border_width (GTK_CONTAINER (dialog->content_box), 8);
+  gtk_container_set_border_width (GTK_CONTAINER (dialog->content_box), 12);
   gtk_container_add (GTK_CONTAINER (dialog->vbox), dialog->content_box);
   gtk_widget_show (dialog->content_box);
 }
@@ -157,7 +157,7 @@ thunar_progress_dialog_shown (ThunarProgressDialog *dialog)
   if (dialog->status_icon == NULL)
     {
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-      dialog->status_icon = gtk_status_icon_new_from_icon_name ("stock_folder-copy");
+      dialog->status_icon = gtk_status_icon_new_from_icon_name ("edit-copy");
 G_GNUC_END_IGNORE_DEPRECATIONS
 
       thunar_progress_dialog_update_status_icon (dialog);
@@ -260,7 +260,11 @@ thunar_progress_dialog_job_finished (ThunarProgressDialog *dialog,
   if (n_views == SCROLLVIEW_THRESHOLD-1)
     {
       /* reparent the content box */
+#if LIBXFCE4UI_CHECK_VERSION (4, 13, 2)
       xfce_widget_reparent (dialog->content_box, dialog->vbox);
+#else
+      gtk_widget_reparent (dialog->content_box, dialog->vbox);
+#endif
 
       /* destroy the scroll win */
       gtk_widget_destroy (dialog->scrollwin);
@@ -375,7 +379,11 @@ thunar_progress_dialog_add_job (ThunarProgressDialog *dialog,
       gtk_widget_show (viewport);
 
       /* move the content box into the viewport */
+#if LIBXFCE4UI_CHECK_VERSION (4, 13, 2)
       xfce_widget_reparent (dialog->content_box, viewport);
+#else
+      gtk_widget_reparent (dialog->content_box, viewport);
+#endif
     }
 
   g_signal_connect_swapped (view, "need-attention",
